@@ -5,8 +5,6 @@ from django.views.generic import TemplateView, CreateView, FormView
 from django.shortcuts import render_to_response
 from django.template import RequestContext
 
-from feedback_form import forms
-
 class CompletedPage(TemplateView):
     template_name = "feedback_form/feedback_done.html"
 
@@ -17,15 +15,16 @@ class ContactFormMixin(object):
     """    
     def form_valid(self, form):
         form.send_email(self.request)
-        return super(ContactFormMixin, self).form_valid(form)
+        return super(ContactFormObject, self).form_valid(form)
 
     def get_success_url(self):		
-        return reverse("completed")
+        return reverse("feedback_form:completed")
 
 	def get_context_data(self, **kwargs):
 		context = super(ContactFormObject, self).get_context_data(**kwargs)
+		context['messagez'] = "1111"
 		return context
 	
 class ContactFormView(ContactFormMixin, FormView):
   template_name="feedback_form/feedback.html"
-  form_class=forms.ContactForm
+  form_class=forms.ContactForm,
